@@ -9,6 +9,6 @@ fn test_agg_trades() {
 
 #[test]
 fn test_l2_snapshot() {
-    let text = fetch_l2_snapshot("binance", MarketType::Spot, "BTCUSDT").unwrap();
+    let text = fetch_l2_snapshot("binance", MarketType::Spot, "BTCUSDT", Some(3)).unwrap();
     assert!(text.starts_with("{"));
 }
