@@ -5,7 +5,7 @@ use std::collections::HashMap;
 
 #[test]
 fn test_l2_snapshot() {
-    let text = fetch_l2_snapshot("bitget", MarketType::Spot, "btc_usdt").unwrap();
+    let text = fetch_l2_snapshot("bitget", MarketType::Spot, "btc_usdt", Some(3)).unwrap();
     let obj = serde_json::from_str::<HashMap<String, Value>>(&text).unwrap();
 
     assert_eq!(obj.get("status").unwrap().as_str().unwrap(), "ok");
