@@ -7,7 +7,7 @@ use test_case::test_case;
 #[test_case(MarketType::InverseSwap, "btcusd")]
 #[test_case(MarketType::LinearSwap, "cmt_btcusdt")]
 fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
-    let text = fetch_l2_snapshot("bitget", market_type, symbol).unwrap();
+    let text = fetch_l2_snapshot("bitget", market_type, symbol, Some(3)).unwrap();
     let obj = serde_json::from_str::<HashMap<String, Value>>(&text).unwrap();
 
     assert!(obj.get("asks").unwrap().as_array().unwrap().len() > 0);
