@@ -9,12 +9,12 @@ fn test_trades() {
 
 #[test]
 fn test_l2_snapshot() {
-    let text = fetch_l2_snapshot("bitstamp", MarketType::Spot, "btcusd").unwrap();
+    let text = fetch_l2_snapshot("bitstamp", MarketType::Spot, "btcusd", Some(3)).unwrap();
     assert!(text.starts_with("{"));
 }
 
 #[test]
 fn test_l3_snapshot() {
-    let text = fetch_l3_snapshot("bitstamp", MarketType::Spot, "btcusd").unwrap();
+    let text = fetch_l3_snapshot("bitstamp", MarketType::Spot, "btcusd", Some(3)).unwrap();
     assert!(text.starts_with("{"));
 }
