@@ -11,7 +11,7 @@ use test_case::test_case;
 #[test_case(MarketType::Move, "BTC-MOVE-2021Q1")]
 #[test_case(MarketType::BVOL, "BVOL/USD")]
 fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
-    let text = fetch_l2_snapshot("ftx", market_type, symbol).unwrap();
+    let text = fetch_l2_snapshot("ftx", market_type, symbol, Some(3)).unwrap();
 
     let obj = serde_json::from_str::<HashMap<String, Value>>(&text).unwrap();
     let result = obj.get("result").unwrap().as_object().unwrap();
