@@ -9,7 +9,7 @@ use test_case::test_case;
 #[test_case(MarketType::InverseSwap, "BTC_USD-R")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
 fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
-    let text = fetch_l2_snapshot("zbg", market_type, symbol).unwrap();
+    let text = fetch_l2_snapshot("zbg", market_type, symbol, Some(3)).unwrap();
     let obj = serde_json::from_str::<HashMap<String, Value>>(&text).unwrap();
 
     assert_eq!(
